package info.bukova.isspst.ui;

import java.lang.reflect.InvocationTargetException;

import org.apache.commons.beanutils.PropertyUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.zkoss.bind.SimpleForm;


/**
 * Třída middle objektu pro validaci formuláře. Umožňuje uložit formulář do datového objektu bez volání validace.
 * Do definice formuláře v ZUL souboru je potřeba uvést: {@code @init(vm.dataForm) }.
 * 
 * @author pepa
 *
 * @param <T> Třída datového objektu
 */
public class BindingForm<T> extends SimpleForm {

	/**
	 * 
	 */
	private static final long serialVersionUID = -9052402254058071780L;
	private T dataBean;
	
	private static final Logger logger = LoggerFactory.getLogger(BindingForm.class);
	
	
	/**
	 * Uloží formulář do předaného objektu.
	 * 
	 * @param object Datový objekt
	 */
	public void bindTo(T object) {
		for (String key : getFieldNames()) {
			// try {
			// BeanUtils.setProperty(object, key, getField(key));
			//
			// } catch (IllegalAccessException e) {
			// logger.warn("Cannot bind value", e);
			// } catch (InvocationTargetException e) {
			// logger.warn("Cannot bind value", e);
			// }
			try
			{
				if (PropertyUtils.getPropertyType(object, key).isPrimitive() 
						&& (getField(key) == null))
				{
					PropertyUtils.setProperty(object, key, 0);
				}
				else
				{
					PropertyUtils.setProperty(object, key, getField(key));
				}
			}
			catch (NoSuchMethodException e)
			{
				logger.warn("Cannot bind value " + key + " (" + e.getMessage() + ")");
				// e.printStackTrace();
			}
			catch (IllegalAccessException e)
			{
				logger.warn("Cannot bind value", e);
				e.printStackTrace();
			}
			catch (InvocationTargetException e)
			{
				logger.warn("Cannot bind value", e);
				e.printStackTrace();
			}
		}
	}
	
	
	/**
	 * Uloží formulář do členského datového objektu.
	 */
	public void bind() {
		bindTo(dataBean);
	}

	public T getDataBean() {
		return dataBean;
	}

	/**
	 * Nastaví datový objekt této instance {@link BindingForm}
	 * 
	 * @param dataBean Datový objekt
	 */
	public void setDataBean(T dataBean) {
		this.dataBean = dataBean;
	}

}
